@@ -42,7 +42,8 @@ from pedal.core.feedback_category import FeedbackStatus
 from pedal.core.report import MAIN_REPORT
 from pedal.sandbox import Sandbox
 from pedal.sandbox.data import format_contexts
-from pedal.sandbox.result import is_sandbox_result
+from pedal.sandbox.exceptions import SandboxException
+from pedal.sandbox.result import is_sandbox_result, unwrap_value
 from pedal.assertions.constants import TOOL_NAME
 from pedal.utilities.text import chomp
 
@@ -54,7 +55,15 @@ class InterpolatedValue:
     def __init__(self, value):
         self.value = value
         self.is_sandboxed = is_sandbox_result(value)
-        self.is_error = not self.is_sandboxed and isinstance(value, Exception)
+        if isinstance(value, Exception):
+            self.is_error = True
+        # Sandboxes with exceptions become their exception
+        elif isinstance(value, Sandbox) and value.exception:
+            self.is_error = True
+            self.value = value.exception
+            self.is_sandboxed = False
+        else:
+            self.is_error = False
         self.report = MAIN_REPORT
         if self.is_sandboxed:
             context_id = value._actual_context_id
@@ -246,11 +255,25 @@ class RuntimeAssertionFeedback(AssertionFeedback):
         """ Create a simple formatted exception message """
         assertion = "The following exception occurred:\n"
         if left.is_error:
-            assertion += self.report.format.output(str(left.value))
+            if not isinstance(left.value, SandboxException):
+                assertion += unwrap_value(left.value.feedback._get_message())
+            else:
+                assertion += str(left.value)
+            #assertion += self.report.format.output(str(left.value))
+            self.suppress_runtime_error(left.value)
         if right.is_error:
-            assertion += self.report.format.output(str(right.value))
+            if not isinstance(right.value, SandboxException):
+                assertion += unwrap_value(right.value.feedback._get_message())
+            else:
+                assertion += str(right.value)
+            #assertion += self.report.format.output(str(right.value))
+            self.suppress_runtime_error(right.value)
         return assertion
 
+    def suppress_runtime_error(self, exception):
+        if hasattr(exception, "feedback") and exception.feedback is not None:
+            exception.feedback.parent = self
+
 
 class RuntimePrintingAssertionFeedback(RuntimeAssertionFeedback):
     """ Variant for handling printing instead of return value"""
@@ -267,6 +290,7 @@ class RuntimePrintingAssertionFeedback(RuntimeAssertionFeedback):
         # Handle whether either side had an error
         if left.is_error or right.is_error:
             assertion = self.format_exception(left, right)
+            return assertion
         # Sandbox
         if isinstance(left.value, Sandbox):
             actual_output = chomp(left.value.raw_output)
