@@ -138,6 +138,7 @@ class Sandbox:
         # Patch in dangerous built-ins
         # Override builtins and mock stuff out
         self._start_mocking(context)
+        self.data['__name__'] = "__main__"
         try:
             # TODO: Support CaitNode and Ast (needs skulpt to support compile better)
             compiled_code = compile(code, filename, 'exec')
@@ -160,6 +161,9 @@ class Sandbox:
         main file will be executed. If ``code`` is given but ``filename`` is
         not, then it is assumed to be instructor code.
 
+        TODO: This should actually return the ExecutionContext that was generated, right?
+            But the user should be able to treat that as if it were the Sandbox...
+
         Args:
             code (str or :py:class:`~pedal.cait.cait_node.CaitNode` or None):
                 The code to execute.
@@ -236,6 +240,8 @@ class Sandbox:
                 value). If the function call failed, the exception will be
                 returned instead.
         """
+        if threaded is None:
+            threaded = self.threaded
         # Confirm that the function_name exists
         if function not in self.functions:
             if function not in self.data:
@@ -291,6 +297,8 @@ class Sandbox:
                 value). If the function call failed, the exception will be
                 returned instead.
         """
+        if threaded is None:
+            threaded = self.threaded
         self.target = target
         code = f"{target} = {code}"
         context_id = self._next_context_id
@@ -431,6 +439,7 @@ class Sandbox:
         self.feedback = runtime_error_function(exception=self.exception, context=[context],
                                                traceback=traceback, location=traceback.line_number,
                                                report=self.report, priority=priority)
+        self.exception.feedback = self.feedback
         return False
 
     def clear_exception(self):
@@ -511,9 +520,9 @@ class Sandbox:
         self.block_function('eval')
         self.block_function('exec')
         self.block_function('globals')
-        self.mock_function('open', mocked._restricted_open)
-        self.mock_function('__import__', mocked._restricted_import)
-        # TODO: This breaks coverage for some reason; it's a builtin?
+        self.block_function('exit')
+        self.mock_function('open', mocked.create_open_function(self.report))
+        self.mock_function('__import__', mocked.create_import_function(self.report))
         self.block_module('pedal')
         self.mock_module('turtle', mocked.MockTurtle(), 'turtles')
         self.mock_module('matplotlib.pyplot', mocked.MockPlt(), 'plotting')
@@ -797,8 +806,10 @@ class Sandbox:
             self.inputs.clear()
         if isinstance(inputs, str):
             self.inputs.append(inputs)
+        elif isinstance(inputs, (int, float, bool)):
+            self.inputs.append(str(inputs))
         elif isinstance(inputs, (list, tuple)):
-            self.inputs.extend(inputs)
+            self.inputs.extend([str(value) for value in inputs])
         elif inputs is not None:
             self.inputs = inputs
         return self
